﻿using System;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();

            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;
            this.chart.Name   = "chart";

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "에러 막대 차트";

            this.chart.ViewXY.LegendBoxes[0].Visible = false;

            AxisX axisX = this.chart.ViewXY.XAxes[0];

            axisX.Title.Text = "빛 파장(nm)";
            axisX.ValueType  = AxisValueType.Number;
            axisX.ScrollMode = XAxisScrollMode.None;

            axisX.SetRange(300, 800);

            AxisY axisY = this.chart.ViewXY.YAxes[0];

            axisY.Title.Text = "식물 성장(mm/월)";

            axisY.SetRange(0, 50);

            ChartHelper.SetDarkFlatStyle(this.chart);

            FreeformPointLineSeries series = new FreeformPointLineSeries(this.chart.ViewXY, axisX, axisY);

            series.ErrorBars.ShowXError   = true;
            series.ErrorBars.ShowYError   = true;
            series.PointsVisible          = true;
            series.PointCountLimitEnabled = true;
            series.PointsType             = PointsType.ErrorPoints;
            series.PointStyle.Width       = 10;
            series.PointStyle.Height      = 10;

            this.chart.ViewXY.FreeformPointLineSeries.Add(series);

            double xError = 3;
            double yError = 2;
            
            int pointCount = 30;

            Random random = new Random();

            double xStep = (axisX.Maximum - axisX.Minimum) / (double)(pointCount - 1);

            SeriesErrorPoint[] pointArray = new SeriesErrorPoint[pointCount];

            for(int i = 0; i < pointCount; i++)
            {
                double x = axisX.Minimum + (double)i * xStep;
                double y = -(x - 550) * (x - 550) / 500 + 400;

                pointArray[i] = new SeriesErrorPoint
                (
                    x + (random.NextDouble() - 0.5) * 2.0 * xError,
                    y + (random.NextDouble() - 0.5) * 2.0 * yError,
                    xError,
                    xError,
                    yError,
                    yError
                );
            }

            series.PointsWithErrors = pointArray;

            double minimumY;
            double maximumY;

            series.GetMinMaxFromXRange(out minimumY, out maximumY, axisX.Minimum, axisX.Maximum, false);

            this.chart.ViewXY.YAxes[0].SetRange(minimumY - yError, maximumY + yError);

            this.chart.ViewXY.XAxes[0].SetRange(300 - xError, 800 + xError);

            this.chart.EndUpdate();
        }

        #endregion
    }
}